@@ -1,7 +1,9 @@
 //! The [`is_read_write`] function.
+//!
+//! [`is_read_write`]: https://docs.rs/rustix/*/rustix/io/fn.is_read_write.html
 
-use crate::{imp, io};
-use imp::fd::AsFd;
+use crate::{backend, io};
+use backend::fd::AsFd;
 
 /// Returns a pair of booleans indicating whether the file descriptor is
 /// readable and/or writable, respectively.
@@ -11,7 +13,7 @@ use imp::fd::AsFd;
 ///
 /// [`is_file_read_write`]: crate::fs::is_file_read_write
 #[inline]
-pub fn is_read_write<Fd: AsFd>(fd: &Fd) -> io::Result<(bool, bool)> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::is_read_write(fd)
+#[cfg_attr(doc_cfg, doc(cfg(all(feature = "fs", feature = "net"))))]
+pub fn is_read_write<Fd: AsFd>(fd: Fd) -> io::Result<(bool, bool)> {
+    backend::io::syscalls::is_read_write(fd.as_fd())
 }
